Settings — django-url2png 0.1 documentation

django-url2png 0.1 documentation

# Settings

- Table of Contents
- index
  previous

# Settings

## API_KEY

The API key url2png gave you.

## SECRET_KEY

The Secret key url2png gave you.

## VIEWPORT

Default: `'1280x1024'`

The viewport for the browser. Max is `'5000x5000'`.

## FULLPAGE

Default: `False`

Capture the entire page, even what is outside of the viewport.

## THUMBNAIL_MAX_WIDTH

Default: `None`

Maximum with of image returned. If not specified image return will be 1:1.

## API_URL

Default: `'http://beta.url2png.com/v6'`

The URL to use in API calls. You shouldn’t need to change this, unless they change it.